Class: Yt::Annotations::Featured
- Defined in:
- lib/yt/annotations/featured.rb
Overview
A Featured annotation is similar to a card, except that it displays in the bottom-left corner and only shows if no cards are present.
Instance Attribute Summary
Attributes inherited from Base
#ends_at, #link, #starts_at, #text
Method Summary
Methods inherited from Card
Constructor Details
This class inherits a constructor from Yt::Annotations::Card